# GladUI

GladUI is a cross-platform C++ GUI engine built with SDL2, wrapped for Python. It aims to provide fast and modern desktop GUI applications and games using native performance and simple Python integration.

## Features

- Written in C++17 with SDL2 for high performance
- Python extension module for easy scripting (`im- Portable: works on Linux, Windows and Mac.
- Very easy to use.
- Powerfull, it's written using a powerfull GUI framework on C++.

## Installation

You can install GladUI via `pip` (source distribution only for now):


NOTE : This is the only command needed for windows, but for MAC and LINUX, you have to install SDL2 (written version 2.32.6), SDL2 mixer (written version : 2.8.1), SDL2 ttf (written version : 2.24.0) and SDL2 image (written version : 2.6.3) on the global path.

```bash
pip install GladUI
